pub struct GenCostPatch {
pub gen_index: usize,
pub bus: BusId,
pub cost: GenCost,
}Expand description
One explicit generator cost patch from a user supplied table.
Fields
gen_index: usizeZero based index into Network::generators.
bus: BusIdBus id expected on that generator, used to catch stale patch tables.
cost: GenCostTrait Implementations
Sourceimpl Clone for GenCostPatch
impl Clone for GenCostPatch
Sourcefn clone(&self) -> GenCostPatch
fn clone(&self) -> GenCostPatch
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenCostPatch
impl Debug for GenCostPatch
Sourceimpl<'de> Deserialize<'de> for GenCostPatch
impl<'de> Deserialize<'de> for GenCostPatch
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GenCostPatch, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GenCostPatch, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for GenCostPatch
impl Serialize for GenCostPatch
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more